==> xl-react-components-0.16.62.tgz: package/tests/unit/xl-react-widget/xl-react-widget-alert-message/xl-widget-alert-message-spec.js <==
import React from 'react';
import R from 'ramda';
import {shallow} from 'enzyme';

import {XlReactWidgetAlertMessage} from '~/app/xl-react-widget/xl-react-widget-alert-message/xl-react-widget-alert-message'; // eslint-disable-line max-len

describe('XlReactWidgetAlertMessage', () => {
    R.forEach((status) => {
        it(`should apply proper CSS class for "${status}" alert message.`, () => {
            const wrapper = shallow(<XlReactWidgetAlertMessage internalState={status}/>);
            expect(wrapper).toHaveClassName(`xl-react-alert-${status}`);
        });
    }, ['error', 'warning', 'success']);

    it('should transclude children element', () => {
        const wrapper = shallow(
            <XlReactWidgetAlertMessage internalState="success">
                <div id="transcluded-child">Text</div>
            </XlReactWidgetAlertMessage>
        );
        expect(wrapper.find('#transcluded-child')).toHaveText('Text');
    });

    it('should be dismissable', () => {
        const onDismiss = jest.fn();
        const props = {
            internalState: 'success',
            onDismiss,
            showClose: true
        };
        const wrapper = shallow(<XlReactWidgetAlertMessage {...props}/>);
        const closeBtn = wrapper.find('.xl-react-btn-close');
        expect(closeBtn).toExist();
        closeBtn.simulate('click');
        expect(onDismiss.mock.calls).toEqual([[]]);
    });

    it('should not be visible if hide property is true', () => {
        const wrapper = shallow(<XlReactWidgetAlertMessage hide={true} internalState="success"/>);
        expect(wrapper.find('div')).not.toExist();
    });
});

==> xl-react-components-0.21.15.tgz: package/tests/unit/xl-react-widget/xl-react-widget-alert-message/xl-widget-alert-message-spec.js <==
import React from 'react';
import R from 'ramda';
import {shallow} from 'enzyme';

import {XlReactWidgetAlertMessage} from '~/app/xl-react-widget/xl-react-widget-alert-message/xl-react-widget-alert-message'; // eslint-disable-line max-len

describe('XlReactWidgetAlertMessage', () => {
    R.forEach((status) => {
        it(`should apply proper CSS class for "${status}" alert message.`, () => {
            const wrapper = shallow(<XlReactWidgetAlertMessage internalState={status}/>);
            expect(wrapper).toHaveClassName(`xl-react-alert-${status}`);
        });
    }, ['error', 'warning', 'success']);

    it('should transclude children element', () => {
        const wrapper = shallow(
            <XlReactWidgetAlertMessage internalState="success">
                <div id="transcluded-child">Text</div>
            </XlReactWidgetAlertMessage>
        );
        expect(wrapper.find('#transcluded-child')).toHaveText('Text');
    });

    it('should be dismissable', () => {
        const onDismiss = jest.fn();
        const props = {
            internalState: 'success',
            onDismiss,
            showClose: true
        };
        const wrapper = shallow(<XlReactWidgetAlertMessage {...props}/>);
        const closeBtn = wrapper.find('.close-icon');
        expect(closeBtn).toExist();
        closeBtn.simulate('click');
        expect(onDismiss.mock.calls).toEqual([[]]);
    });

    it('should not be visible if hide property is true', () => {
        const wrapper = shallow(<XlReactWidgetAlertMessage hide={true} internalState="success"/>);
        expect(wrapper.find('div')).not.toExist();
    });
});
